======================
Continuous Integration
======================

To make sure that changes do not break Kolla we use Continuous Integration (CI
in short) on Opendev Zuul platform.

Distribution, architecture, build type coverage
===============================================

There are several builds running on CI. We cover each supported distribution on
x86-64 architecture and Debian/source builds on AArch64.

Allowed to fail
===============

During Wallaby cycle we added support for 'allowed to fail' images.

The ``allowed-to-fail`` option in ``kolla-build.conf`` file (generated by
``tests/playbooks/run.yml`` lists images which are allowed to fail during CI
build without bringing whole build down.

Main use will be situation when we need to wait for other projects to fix
problems blocking build of image.

.. note::
    This is meant to be used on CI in emergency situation.
